@@ -125,7 +125,8 @@ class Key:
 		}
 
 		universe = ['a', 'as', 'b', 'c', 'cs', 'd', 'ds', 'e', 'f', 'fs', 'g', 'gs'] * 2
-		self.universe = universe
+		self.universal_chords = chords
+		self.universal_notes = universe
 		W = 2
 		H = 1
 		if 'major' in name.lower() and name[0].lower() in universe:
@@ -215,6 +216,7 @@ class Key:
 
 				self_chords[name] = chords[name]
 				index += rough_modes['ionian']['steps'][step]
+
 		self.chords = self_chords
 
 		if 'major' in self.name:
@@ -229,6 +231,22 @@ class Key:
 	def list_chords(self):
 		return [i for i in list(self.chords.keys())]
 
+	def list_chords_in_mode(self, modename):
+		chords_in_mode = []
+		mode_notes = self.list_notes_in_mode(modename)
+		for i in range(len(mode_notes)):
+			num = self.numerals[i]
+			if num.isupper() and 'd' not in num:
+				name = mode_notes[i] + '_major'
+			elif num.isupper() and 'd' in num:
+				name = mode_notes[i] + '_major_dim'
+			elif num.islower() and 'd' not in num:
+				name = mode_notes[i] + '_minor'
+			elif num.islower() and 'd' in num:
+				name = mode_notes[i] + '_dim'
+			chords_in_mode.append(name)
+		return chords_in_mode
+
 	def list_modes(self):
 		return list_modes()
 
@@ -261,19 +279,26 @@ class Key:
 			new_dict[key] = [i[octave] for i in self.chords[key]]
 		return new_dict
 
+	def chords_in_mode(self, modename):
+		new_dict = {}
+		chord_names = self.list_chords_in_mode(modename)
+		for i in chord_names:
+			new_dict[i] = self.universal_chords[i]
+		return new_dict
+
 	def notes_in_pentatonic_minor(self):
 		new_dict = {}
 		notes = Notes()
 		if self.seniority == 'minor':
 			scale = self.list_notes_in_mode('ionian')
 			try:
-				flatted_three = self.universe[self.universe.index(scale[2])]
+				flatted_three = self.universal_notes[self.universal_notes.index(scale[2])]
 			except:
-				flatted_three = self.universe[self.universe.index('gs')]
+				flatted_three = self.universal_notes[self.universal_notes.index('gs')]
 			try:
-				flatted_seventh = self.universe[self.universe.index(scale[6])]
+				flatted_seventh = self.universal_notes[self.universal_notes.index(scale[6])]
 			except:
-				flatted_seventh = self.universe[self.universe.index('gs')]
+				flatted_seventh = self.universal_notes[self.universal_notes.index('gs')]
 
 			pentatonics = [scale[0], flatted_three, scale[3], scale[4], flatted_seventh]
 
